@@ -504,7 +504,7 @@ class RasterDataset(XRasterBase):
 
         Returns
         -------
-        :obj:`dask.Delayed`:
+        :obj:`dask.Delayed` | :obj:`dask.Array` | None:
             If the data array is a dask array and compute
             is True. Otherwise None is returned.
 
